==> tuia-advert-center-api-2.3.84-sources.jar: cn/com/duiba/tuia/core/api/dto/QualificationsAuditDataDto.java <==
package cn.com.duiba.tuia.core.api.dto;

public class QualificationsAuditDataDto {
    /**
     * 审核的账号id
     */
    private Long accountId;
    /**
     * 广告主名称
     */
    private String accountName;

    /**
     * 一级代理商id
     */
    private Long levelOneAgentId;

    /**
     * 一级代理商名称
     */
    private String levelOneAgentName;

    /**
     * ae id
     */
    private Long aeId;
    private String aeName;
    private Long sellId;
    private String sellName;

    /**
     * 行业
     */
    private String industry;

    private Long qualificationId;

    /**
     * 资质图片
     */
    private String qualificationUrl;

    /**
     * 资质内容
     */
    private String qualificationContent;

    /**
     * 审核动作类型
     */
    private Integer checkType;
    /**
     * 拒绝或冻结理由
     */
    private String reason;

    /**
     * 审核人.
     */
    private String reviewer;

    /**
     * 进审时间
     */
    private String enterCheckTime;
    /**
     * 审核时间
     */
    private String checkTime;
    /**
     * 审核时长
     */
    private Long checkCostTime;

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public String getAccountName() {
        return accountName;
    }

    public void setAccountName(String accountName) {
        this.accountName = accountName;
    }

    public Long getLevelOneAgentId() {
        return levelOneAgentId;
    }

    public void setLevelOneAgentId(Long levelOneAgentId) {
        this.levelOneAgentId = levelOneAgentId;
    }

    public String getLevelOneAgentName() {
        return levelOneAgentName;
    }

    public void setLevelOneAgentName(String levelOneAgentName) {
        this.levelOneAgentName = levelOneAgentName;
    }

    public Long getAeId() {
        return aeId;
    }

    public void setAeId(Long aeId) {
        this.aeId = aeId;
    }

    public String getAeName() {
        return aeName;
    }

    public void setAeName(String aeName) {
        this.aeName = aeName;
    }

    public Long getSellId() {
        return sellId;
    }

    public void setSellId(Long sellId) {
        this.sellId = sellId;
    }

    public String getSellName() {
        return sellName;
    }

    public void setSellName(String sellName) {
        this.sellName = sellName;
    }

    public String getIndustry() {
        return industry;
    }

    public void setIndustry(String industry) {
        this.industry = industry;
    }

    public Long getQualificationId() {
        return qualificationId;
    }

    public void setQualificationId(Long qualificationId) {
        this.qualificationId = qualificationId;
    }

    public String getQualificationUrl() {
        return qualificationUrl;
    }

    public void setQualificationUrl(String qualificationUrl) {
        this.qualificationUrl = qualificationUrl;
    }

    public String getQualificationContent() {
        return qualificationContent;
    }

    public void setQualificationContent(String qualificationContent) {
        this.qualificationContent = qualificationContent;
    }

    public Integer getCheckType() {
        return checkType;
    }

    public void setCheckType(Integer checkType) {
        this.checkType = checkType;
    }

    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }

    public String getReviewer() {
        return reviewer;
    }

    public void setReviewer(String reviewer) {
        this.reviewer = reviewer;
    }

    public String getEnterCheckTime() {
        return enterCheckTime;
    }

    public void setEnterCheckTime(String enterCheckTime) {
        this.enterCheckTime = enterCheckTime;
    }

    public String getCheckTime() {
        return checkTime;
    }

    public void setCheckTime(String checkTime) {
        this.checkTime = checkTime;
    }

    public Long getCheckCostTime() {
        return checkCostTime;
    }

    public void setCheckCostTime(Long checkCostTime) {
        this.checkCostTime = checkCostTime;
    }
}

==> tuia-advert-center-api-2.6.17-sources.jar: cn/com/duiba/tuia/core/api/dto/QualificationsAuditDataDto.java <==
package cn.com.duiba.tuia.core.api.dto;

import java.util.List;

public class QualificationsAuditDataDto {
    private Long id;
    /**
     * 审核的账号id
     */
    private Long accountId;
    /**
     * 广告主名称
     */
    private String accountName;

    /**
     * 一级代理商id
     */
    private Long levelOneAgentId;

    /**
     * 一级代理商名称
     */
    private String levelOneAgentName;

    /**
     * ae id
     */
    private Long aeId;
    private String aeName;
    private Long sellId;
    private String sellName;

    /**
     * 行业
     */
    private String industry;

    private Long qualificationId;

    /**
     * 资质图片
     */
    private String qualificationUrl;
    /** 资质图片url List */
    private List<String> qualificationUrlList;
    /** 资质资源名称 */
    private String qualificationName;
    /**
     * 资质内容
     */
    private String qualificationContent;

    /**
     * 审核动作类型
     */
    private Integer checkType;
    /**
     * 拒绝或冻结理由
     */
    private String reason;

    /**
     * 审核人.
     */
    private String reviewer;

    /**
     * 进审时间
     */
    private String enterCheckTime;
    /**
     * 审核时间
     */
    private String checkTime;
    /**
     * 审核时长
     */
    private Long checkCostTime;
    /** 操作人IP */
    private String operatorIp;
    /** 设备品牌型号 */
    private String deviceType;
    /** 浏览器名称 */
    private String browerName;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public String getAccountName() {
        return accountName;
    }

    public void setAccountName(String accountName) {
        this.accountName = accountName;
    }

    public Long getLevelOneAgentId() {
        return levelOneAgentId;
    }

    public void setLevelOneAgentId(Long levelOneAgentId) {
        this.levelOneAgentId = levelOneAgentId;
    }

    public String getLevelOneAgentName() {
        return levelOneAgentName;
    }

    public void setLevelOneAgentName(String levelOneAgentName) {
        this.levelOneAgentName = levelOneAgentName;
    }

    public Long getAeId() {
        return aeId;
    }

    public void setAeId(Long aeId) {
        this.aeId = aeId;
    }

    public String getAeName() {
        return aeName;
    }

    public void setAeName(String aeName) {
        this.aeName = aeName;
    }

    public Long getSellId() {
        return sellId;
    }

    public void setSellId(Long sellId) {
        this.sellId = sellId;
    }

    public String getSellName() {
        return sellName;
    }

    public void setSellName(String sellName) {
        this.sellName = sellName;
    }

    public String getIndustry() {
        return industry;
    }

    public void setIndustry(String industry) {
        this.industry = industry;
    }

    public Long getQualificationId() {
        return qualificationId;
    }

    public void setQualificationId(Long qualificationId) {
        this.qualificationId = qualificationId;
    }

    public String getQualificationUrl() {
        return qualificationUrl;
    }

    public void setQualificationUrl(String qualificationUrl) {
        this.qualificationUrl = qualificationUrl;
    }

    public String getQualificationContent() {
        return qualificationContent;
    }

    public void setQualificationContent(String qualificationContent) {
        this.qualificationContent = qualificationContent;
    }

    public Integer getCheckType() {
        return checkType;
    }

    public void setCheckType(Integer checkType) {
        this.checkType = checkType;
    }

    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }

    public String getReviewer() {
        return reviewer;
    }

    public void setReviewer(String reviewer) {
        this.reviewer = reviewer;
    }

    public String getEnterCheckTime() {
        return enterCheckTime;
    }

    public void setEnterCheckTime(String enterCheckTime) {
        this.enterCheckTime = enterCheckTime;
    }

    public String getCheckTime() {
        return checkTime;
    }

    public void setCheckTime(String checkTime) {
        this.checkTime = checkTime;
    }

    public Long getCheckCostTime() {
        return checkCostTime;
    }

    public void setCheckCostTime(Long checkCostTime) {
        this.checkCostTime = checkCostTime;
    }

    public String getOperatorIp() {
        return operatorIp;
    }

    public void setOperatorIp(String operatorIp) {
        this.operatorIp = operatorIp;
    }

    public String getDeviceType() {
        return deviceType;
    }

    public void setDeviceType(String deviceType) {
        this.deviceType = deviceType;
    }

    public String getBrowerName() {
        return browerName;
    }

    public void setBrowerName(String browerName) {
        this.browerName = browerName;
    }

    public List<String> getQualificationUrlList() {
        return qualificationUrlList;
    }

    public void setQualificationUrlList(List<String> qualificationUrlList) {
        this.qualificationUrlList = qualificationUrlList;
    }

    public String getQualificationName() {
        return qualificationName;
    }

    public void setQualificationName(String qualificationName) {
        this.qualificationName = qualificationName;
    }
}
